#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: Guimup
# PROJECT HOMEPAGE 	: http://www.coonsden.com/
# SOURCES          	: http://zenwalk.pinguix.com/user-accounts/skywatcher/Guimup
#
# MAINTAINER       	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# LATEST REVISION   : 2009-06-03 
#
# BUILD-ONLY DEPS	: -
# NOTES				: -

### Checking for unbound variables
set -u

### Setting main variables
NAME="guimup"
VERSION="0.2.0"
ARCH="i686"
CPU="i686"
BUILD=62.1

NOME="Guimup"

URL=http://zenwalk.pinguix.com/user-accounts/skywatcher/$NAME/$VERSION

HOMEPAGE="http://www.coonsden.com/"
DESCRIPTION="GTK client for MPD"
SRCLNK=$URL/$NOME-"$VERSION"-src.tar.gz

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=`echo $SRCLNK | rev | cut -d/ -f1 | rev`
SRCDIR=$CWD/$NOME-"$VERSION"
ICONROOT=$PKGDIR/usr/share/icons/hicolor/

DOCS="AUTHORS ChangeLog COPYING FAQ INSTALL NEWS README"

NJOBS="-j2"
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION
mkdir -p $PKGDIR/usr/share/applications
mkdir -p $ICONROOT

### Checking if sources are present. If not, download them
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Extracting source
tar xfv $SRCPKG

### Building
cd $SRCDIR
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var --mandir=/usr/man || exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1
#~ python setup.py install --prefix=/usr --root=$PKGDIR || exit 1

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $SRCDIR
cp -av $DOCS $PKGDIR/usr/doc/$NAME-$VERSION
find $PKGDIR/usr/man -type f -exec gzip -9 {} \;

### Adding build-file and other stuff to the package
cp -av $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x -v $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: GUIMUP is a client for the music player daemon (MPD) written in C++
$NAME: and GTKmm. The program can be used with most Linux desktops but, as
$NAME: a GTK program, is best suited for GNOME and XFCE.
$NAME: The focus of the program is on mouse handling: playlist management  
$NAME: is done entirely by drag-&-drop; playback functions are directly 
$NAME: accessible from the system tray.
$NAME: Guimup is covered by the General Public License (GPL).
$NAME: 
$NAME: $HOMEPAGE
EOF

### Desktop entry
cat > $PKGDIR/usr/share/applications/$NAME.desktop << EOF
[Desktop Entry]
Name=Guimup
Comment= GTK frontend to MPD
Exec=guimup
Icon=guimup
Type=Application
Categories=Application;GTK;AudioVideo;
Terminal=false
StartupNotify=true
Encoding=UTF-8
EOF

### Icon
for dir in 32 48 64 128; do \
	mkdir -pv $ICONROOT/"$dir"x"$dir"/apps/	
	cp -av $SRCDIR/Icons/guimup$dir.png $ICONROOT/"$dir"x"$dir"/apps/
	cd $ICONROOT/"$dir"x"$dir"/apps/
	mv guimup$dir.png guimup.png
done
	
### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Unnedeed stuff
rm -fr $PKGDIR/usr/doc/guimup

### Making the package
makepkg -l y -c n $CWD/$PKG.tgz

### md5
cd $CWD
md5sum $PKG.tgz > $PKG.md5

### dep
depfinder $PKG.tgz > $PKG.dep

### txt
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
rm -fr $PKG.src
for link in $URL/$0 $SRCLNK
	do echo $link >> $PKG.src
done

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

### Done. Ciao!
